EOS - The AMOR focusing reflectometry data reduction software
-------------------------------------------------------------

.. image:: https://img.shields.io/pypi/v/amor-eos.svg
        :target: https://pypi.python.org/pypi/amor-eos/


Software repository for the neutron reflectometer Amor at the Paul Scherrer Institut, Switzerland

Reduction of the raw files (.hdf) to reflectivity files in one of the representations of the **ORSO reflectivity file format**:

  eos --help

visualisation of the content of a raw file (.hdf):

  events2histogram.py

:TODO: real readme for final system needed.

Installation
------------
Create a virtual python environment (>3.8) and install the PyPI package:

  pip install amor-eos

On Windows you can also use the binary eos.exe that you find in the
[GitHub Releases]([https://github.com/jochenstahn/amor/releases/latest) section
